@@ -24,7 +24,9 @@ import binascii
 import logging
 import time
 from array import array
+from contextlib import contextmanager
 from struct import *
+from typing import Optional
 
 import usb
 
@@ -133,6 +135,17 @@ class gnuk_token(object):
     def release_gnuk(self):
         self.__devhandle.releaseInterface()
 
+    @contextmanager
+    def release_on_exit(self, *args, **kwds):
+        """
+        Release GNUK device once finished, to not block other smart card services
+        trying to claim it
+        """
+        try:
+            yield self
+        finally:
+            self.release_gnuk()
+
     def stop_gnuk(self):
         self.__devhandle.releaseInterface()
         if self.__hid_intf:
@@ -705,7 +718,7 @@ def gnuk_devices_by_vidpid():
                 break
 
 
-def get_gnuk_device(verbose=True, logger: logging.Logger = None):
+def get_gnuk_device(verbose=True, logger: Optional[logging.Logger] = None):
     from usb import USBError
 
     candidates = []
@@ -734,7 +747,7 @@ def get_gnuk_device(verbose=True, logger: logging.Logger = None):
         except Exception:
             pass
     if not icc and candidates:
-        raise OnlyBusyICCError("Found only busy ICC")
+        raise OnlyBusyICCError(f"Found only busy ICC: {candidates}")
     if not icc:
         raise ValueError("No ICC present")
     status = icc.icc_get_status()
